@@ -68,7 +68,7 @@ class Stack:
             stck.push(self.pop())
         return stck
     @classmethod
-    def merge(self, s1: Stack, s2: Stack):
+    def merge(self, s1, s2):
         try:
             stck = Stack()
             tmp1 = s1.__top
@@ -84,16 +84,16 @@ class Stack:
         except Exception as ex:
             print("Error, %s" %ex)
     @classmethod
-    def swap(self, s1: Stack, s2: Stack):
+    def swap(self, s1, s2):
         bid1 = Stack()
         bid2 = Stack()
-        while not t1.empty():
-            bid1.push(t1.pop())
-        while not t2.empty():
-            bid2.push(t2.pop())
+        while not s1.empty():
+            bid1.push(s1.pop())
+        while not s2.empty():
+            bid2.push(s2.pop())
         while not bid1.empty():
-            t2.push(bid1.pop())
+            s2.push(bid1.pop())
         while not bid2.empty():
-            t1.push(bid2.pop())
+            s1.push(bid2.pop())
         del bid1, bid2
     
\ No newline at end of file
